#!/bin/ksh
#
# HIRAS test case
#
# Usage: ./hiras_run.sh
#
# The input file is a NSR file from direct readout. AAPP supports FSR also.
#
# AAPP_PREFIX must be defined as an environment variable
#
# The script carries out the following steps. Note that in general users will
# not want to run all the steps, i.e. users do not need both l1d BUFR and l1c
# BUFR.
#
# 1) Decode a HIRAS HDF file to AAPP l1c format.
# 2) Extract channels using the CrIS channel selection (see
#    $DIR_PREPROC/HIRAS.fdf or HIRAS_FSR.fdf)
# 3) BUFR encode (with ecCodes) using the CrIS FSR BUFR sequence, as defined by
#    NOAA. Note that it is expected that CMA will define their own BUFR format
#    eventually.
# 4) Run atovpp to convert to l1d, again using the specification in
#    $DIR_PREPROC/HIRAS.fdf. The default is not to apply spatial thinning, but
#    you can edit the fdf file to change this if wanted.
# 5) BUFR encode the l1d, using the local Met Office BUFR sequence (as used for
#    CrIS) and BUFRDC. This sequence should NOT be used for international data
#    exchange. It is intended for use by the Met Office and UM partners.
#
# 18/4/2019
# 02/12/2019 Set up BUFR_TABLES, MASTER_TABLE, LOCAL_TABLE
############################################################################ 

[ $AAPP_PREFIX ] || { echo "AAPP_PREFIX is not defined"; exit; }
[ -d "$AAPP_PREFIX" ] || { echo "AAPP_PREFIX is not a directory"; exit; }

. "$AAPP_PREFIX/ATOVS_CONF"               #AAPP environment

WRK=$PWD/work
level1=$PWD/level1

mkdir -p $WRK
cd $level1
infile=$(ls *.HDF)
l1cfile=${infile%.HDF}.l1c

cd $WRK
echo "run hiras_sdr"
hiras_sdr -o $l1cfile $level1/$infile

echo "run hiras_channels"
hiras_chanfile=${l1cfile%.l1c}_channels.l1c
hiras_channels $l1cfile $hiras_chanfile

echo "run eccodes_encodebufr_1c"
eccodes_encodebufr_1c -i $hiras_chanfile HIRAS

echo "run atovpp"
atovpp -i HIRAS -g HIRAS -f $l1cfile

echo "run aapp_encodebufr_1c"
export BUFR_TABLES=$AAPP_PREFIX/AAPP/data/bufrtables/
export MASTER_TABLE=15
export LOCAL_TABLE=1

l1dfile=${l1cfile%.l1c}.l1d
aapp_encodebufr_1c -i $l1dfile HIRAS1D
mv ${l1dfile%.l1d}.bufr ${l1dfile}.bufr

echo "outputs are in $WRK"


